==> next-ft-api-client-3.7.0.tgz: package/README.md <==
# next-ft-api-client
No caching, no models, no complexity, none of that or any of that.

```
npm install --save next-ft-api-client
```

```js
var api = require('next-ft-api-client');
```

## `.content(opts)` - get V2 content
- `uuid` - uuid (or array of uuids) of wanted content
- `type` - type of content request (Article or Image, only used for debug purposes)
- `useElasticSearch` - whether or not to use elastic search

If `uuid` is a string return a Promise that resolves with a V2 content object, if `uuid` is an array, returns a Promise that resolves with an array of V2 content objects.

## `.contentAnnotatedBy(opts)`
- `uuid` - uuid of thing wanted to select content by
- `count` - number of items of content to return (default 10)
- `useElasticSearch` - whether or not to use elastic search

Returns with a Promise that resolves with an array of V2 content objects.

## `.contentLegacy(opts)` - get V1 content
- `uuid` - uuid of wanted content
- `useElasticSearch` - whether or not to use elastic search

Returns with a Promise that resolves with a V1 content object.

## `.lists(opts)`
- `uuid` - uuid of wanted list

Returns with a Promise that resolves with a list.

## `.organisations(opts)`
- `uuid` - uuid of wanted organisation

Returns with a Promise that resolves with an organisation.

## `.people(opts)`
- `uuid` - uuid of wanted person

Returns with a Promise that resolves with a person.

## `.searchLegacy(opts)`
- `query` - query to search against
- `count` - number of items of content to return (default 10)
- `offset` - number of items of content to offset by (default 0)
- `useLegacyContent` - if `true` return an array of v1 content items, otherwise return array of v2 content items
- `useElasticSearch` - whether or not to use elastic search for underlying content lookups (currently using elastic search to do actual search is not supported…)

Returns with a Promise that resolves with an array of V1 or V2 content objects (depending on options).

## `.things(opts)`
- `uuid` - uuid of wanted thing

Returns with a Promise that resolves with a thing.

## `.mapping(uuid, taxonomy)`
- `uuid` - uuid of thing to map
- `taxonomy` - taxonomy of thing to map

Returns with a Promise that resolves with the mapped concept.

==> next-ft-api-client-3.9.5.tgz: package/README.md <==
# next-ft-api-client
No caching, no models, no complexity, none of that or any of that.

```
npm install --save next-ft-api-client
```

```js
var api = require('next-ft-api-client');
```

## `.content(opts)` - get V2 content
- `uuid` - uuid (or array of uuids) of wanted content
- `type` - type of content request (Article or Image, only used for debug purposes)
- `useElasticSearch` - whether or not to use elastic search

If `uuid` is a string return a Promise that resolves with a V2 content object, if `uuid` is an array, returns a Promise that resolves with an array of V2 content objects.

## `.contentAnnotatedBy(opts)`
- `uuid` - uuid of thing wanted to select content by
- `count` - number of items of content to return (default 10)
- `useElasticSearch` - whether or not to use elastic search

Returns with a Promise that resolves with an array of V2 content objects.

## `.contentLegacy(opts)` - get V1 content
- `uuid` - uuid of wanted content
- `useElasticSearch` - whether or not to use elastic search

Returns with a Promise that resolves with a V1 content object.

## `.lists(opts)`
- `uuid` - uuid of wanted list

Returns with a Promise that resolves with a list.

## `.organisations(opts)`
- `uuid` - uuid of wanted organisation

Returns with a Promise that resolves with an organisation.

## `.people(opts)`
- `uuid` - uuid of wanted person

Returns with a Promise that resolves with a person.

## `.searchLegacy(opts)`
- `query` - query to search against. Either free text, a taxonomysearch e.g. `peopleId:"Mhkasfgoasfgjh"` or, when using elastic search, an elastic search query object
- `fields` - When using elastic search an array of fields to return
- `count` - number of items of content to return (default 10)
- `offset` - number of items of content to offset by (default 0)
- `useLegacyContent` - if `true` return an array of v1 content items, otherwise return array of v2 content items
- `useElasticSearch` - whether or not to use elastic search for underlying content lookups (currently using elastic search to do actual search is not supported…)

Returns with a Promise that resolves with an array of V1 or V2 content objects (depending on options).

## `.things(opts)`
- `uuid` - uuid of wanted thing

Returns with a Promise that resolves with a thing.

## `.mapping(uuid, taxonomy)`
- `uuid` - uuid of thing to map
- `taxonomy` - taxonomy of thing to map

Returns with a Promise that resolves with the mapped concept.
